// frameV2.scad, C.W. Spangler, last modified 2014-10-31
// create full frame for spool and bearings, Version 2, additional features
//********************************************************************************
// edit/comment "inside width" (IWinches) and "wheelbase" (WBinches) as needed
//
// to print on medium-sized (or larger) print beds
// IWinches=2.86; WBinches=3.50; // for 8" MakerBot older 1Kg spool   (2.80" wide)
// IWinches=2.95; WBinches=3.50; // for 8" MakerBot older 1Kg spool   (2.88" wide)
   IWinches=3.10; WBinches=3.50; // for 8" MakerBot newer 1Kg spool   (3.00" wide)
// IWinches=3.30; WBinches=3.50; // for 7.7" MonoPrice 1Kg spool      (3.15" wide)
// IWinches=3.56; WBinches=3.75; // for 8.5" MakerBot XL 5Lb spool    (3.50" wide)
// IWinches=7.06; WBinches=3.75; // for 8.5" MakerBot XXL 10Lb spool  (7.00" wide)
// IWinches=3.95; WBinches=3.00; // for ~6" wiring-type spool         (3.88" wide)
// IWinches=4.15; WBinches=3.00; // for warped ~6" wiring-type spool  (4.12" wide)
//
// to print on  Micro3D (M3D) (oriented with "x" on the 113mm build plate dimension)
// print bed 113mm x 109mm, max IW=99mm=3.89", max WB=79mm=3.11"
// IWinches=2.86; WBinches=3.05; // for 8" MakerBot older 1Kg spool   (2.80" wide)
// IWinches=2.95; WBinches=3.05; // for 8" MakerBot older 1Kg spool   (2.88" wide)
// IWinches=3.10; WBinches=3.05; // for 8" MakerBot newer 1Kg spool   (3.00" wide)
// IWinches=3.30; WBinches=3.05; // for 7.7" MonoPrice 1Kg spool      (3.15" wide)
// IWinches=3.56; WBinches=3.05; // for 8.5" MakerBot XL 5Lb spool    (3.50" wide)
//
// to print on  Micro3D (M3D) (oriented with "x" on the 109mm build plate dimension)
// print bed 109mm x 113mm, max IW=103mm=4.05", max WB=75mm=2.95"
// IWinches=3.95; WBinches=2.90; // for ~6" wiring-type spool         (3.88" wide)
//
// to print on MakerBot Mini or Printrbot Simple
// print bed 100mm x 100mm, max IW=90mm=3.54", max WB=66mm=2.59"
// IWinches=2.86; WBinches=2.55; // for 8" MakerBot older 1Kg spool   (2.80" wide)
// IWinches=2.95; WBinches=2.55; // for 8" MakerBot older 1Kg spool   (2.88" wide)
// IWinches=3.10; WBinches=2.55; // for 8" MakerBot newer 1Kg spool   (3.00" wide)
// IWinches=3.30; WBinches=2.55; // for 7.7" MonoPrice 1Kg spool      (3.15" wide)
//

mmperinch=25.4; IWmm=IWinches*mmperinch; WBmm=WBinches*mmperinch;

$fn=50;

//********************************************************************************
// switches to change features

onecorneronly= false; // switch to print only one corner, for test fit of pin
splitends=     false; // switch to leave gaps in the ends instead of full perimeter
baseend=       false; // switch for extra base inside/along ends of frame
baseside=      false; // switch for extra base inside/along sides of frame
recessend=     true ; // switch for end recesses;  NOT PARAMETRIC; for 608 bearings
recessside=    true ; // switch for side recesses; NOT PARAMETRIC; for 608 bearings
extraraft=     true ; // switch for 3/4 circles for extra raft at the corners
rr=10.0;              // radius for 3/4 circles for extra raft

//********************************************************************************
// constants w/ the notation **ADJ** might need adjustment for your printer/filament

bor=22.0/2;           // bearing outer radius (for 608 bearing, 22mm diameter)
bir=8.15/2;           // bearing inner radius (for 608 bearing, 8mm diameter) **ADJ**
bw=7.0;               // bearing width        (for 608 bearing, 7mm wide)
bcw=bw+2.0;           // bearing clearance width   (2mm added for "washers" & space)
bcr=bor+1.0;          // bearing clearance radius  (1mm clearance added)

sir=6.50/2;           // support inside radius (for 1/4" = 6.35mm diameter) **ADJ**

wor=bir+2.0;          // "washer" outer radius
wir=bir+0.25;         // "washer" inner radius
wt=0.75;              // "washer" thickness

ft=5.0;               // frame thickness
st=10.0;              // support thickness
fh=bcr+bor;           // frame height
pl=ft+bcw+st;         // pin length
eo=pl+ft;             // end offset for recess
so=ft+bcr+bor+ft;     // side offset for recess

po=bcr+ft;            // pin offset, distance from end to center of pin
halfWB=WBmm/2; halfside=po+halfWB;
halfIW=IWmm/2; halfend=ft+halfIW;

//****************************************************************************

// construct one corner for pin test fit, or one side, or full frame
//
if (onecorneronly)
  quarterframe();
  else {mirror([0,1,0]) halfframe(); if(!splitends) halfframe();}


// "halfframe" module
// construct one side of frame
//
module halfframe()
  {quarterframe(); mirror([1,0,0]) quarterframe();}


// "quarterframe" module
// place one corner correctly (on z=0, x/y ready for mirroring)
//
module quarterframe()
  {translate([-halfside,-halfend,0]) voidedcorner();}


// "voidedcorner" module
// add void for pin and bearing to corner
//
module voidedcorner()
{
  difference()
    {roundinner();
     translate([bcr+ft,0,bcr]) rotate([-90,0,0]) rollervoid();
    }
}

// "roundinner" module
// round off inner corner, iff the frame is split
//
module roundinner()
{
  if(splitends)
    difference()
      {roundouter();
       translate([2,pl-2,0]) difference()
         {translate([-2,0,0]) cube([2,2,fh]); cylinder(r=2,h=fh,$rn=100);}
      }
    else roundouter();
}

// "roundouter" module
// round off outer corner
//
module roundouter()
{
  difference()
    {solidcorner();
     translate([2,2,0]) difference()
       {translate([-2,-2,0]) cube([2,2,fh]); cylinder(r=2,h=fh,$fn=100);}
    }
}


// "solidcorner" module
// create one corner of the frame, before voids
//
module solidcorner()
{
// half side frame - optional recess, NOT PARAMETRIC, only for 608 bearings
  if(recessside && (halfside > (so+5)))
    {difference()
      {cube([halfside+.01,ft,fh]);
       translate([so,-fh/2,fh/2]) rotate([0,90,0]) cylinder(h=halfside,r=15);
      }
    }
    else {cube([halfside+.01,ft,fh]);}

// half end frame - optional recess, NOT PARAMETRIC, only for 608 bearings
  if(splitends) 
    {cube([ft,pl,fh]);}
    else if(recessend && (halfend > (eo+5)))
      {difference()
        {cube([ft,halfend+.01,fh]);
         translate([-fh/2,eo,fh/2]) rotate([-90,0,0]) cylinder(h=halfend,r=15);
        }
      }
      else {cube([ft,halfend+.01,fh]);}

// support for pin end, upper inner part curved to match bearing
  translate([ft,ft+bcw,0]) cube([bcr,st,fh]);   // half of support toward end
  translate([po,0,0])      cube([bor,pl,bcr]);  // bottom quarter of support
  translate([po,0,bcr]) rotate([-90,0,0]) cylinder(r=bor,h=ft+bcw+st,$fn=100);

// optional base along sides
  if(baseside)
    {translate([ft+bcr+bor,ft,0]) cube([halfside-(ft+bcr+bor)+.01,pl-ft,ft]);}

// optional base along ends
  if(baseend && !splitends)
    {translate([ft,pl,0]) cube([bcr+bor,halfend-pl+.01,ft]);}

// optional raft extension (short 3/4 circle cylinder, offset by .5mm)
  if(extraraft)
    {translate([-0.5,-0.5,0]) difference()
      {cylinder(r=rr,h=.20); cube([rr,rr,.20]);}
    }
  if(extraraft && splitends)
    {translate([-0.5,pl+0.5,0]) rotate([0,0,-90]) difference()
      {cylinder(r=rr,h=.20); cube([rr,rr,.20]);}
    }
}


// "rollervoid" module
// create void for pin and bearing
//
module rollervoid()
{
  translate([0,0,pl])        cylinder(h=0.01,r=sir);     // make hole go through inner
  translate([0,0,0])         cylinder(h=pl,r=sir,$fn=50);
  translate([0,0,0])         cylinder(h=ft+bcw+.25,r=bir,$fn=50);
  translate([0,0,-0.01])     cylinder(h=0.01,r=bir);     // make hole go through outer

  translate([0,0,ft+bcw-wt]) cylinder(h=wt+.25,r=wir);   // inner "washer"
  translate([0,0,ft+bcw-wt]) difference() {cylinder(h=wt,r=bcr); cylinder(h=wt,r=wor);}

  translate([0,0,ft+wt])     cylinder(h=bcw-2*wt,r=bcr); // bearing space w/ clearances

  translate([0,0,ft])        cylinder(h=wt,r=wir);       // outer "washer"
  translate([0,0,ft])        difference() {cylinder(h=wt,r=bcr); cylinder(h=wt,r=wor);}
  
}